==> qspot_0.0.1-1.tar.gz: qspot-0.0.1/src/qspotify_src/callbacks.h <==
//callbacks.h: libopenspotify callbacks
#ifndef CALLBACKS_H
#define CALLBACKS_H

#include "spotifysession.h"

// libopenspotify callback functions

sp_session_callbacks g_callbacks = {
    &Spotify::Session::loggedInCallback,
    &Spotify::Session::loggedOutCallback,
    &Spotify::Session::metadataUpdatedCallback,
    &Spotify::Session::connectionErrorCallback,
    &Spotify::Session::messageToUserCallback,
    &Spotify::Session::notifyMainThreadCallback,
    &Spotify::Session::musicDeliveryCallback,
    &Spotify::Session::playTokenLostCallback,
    &Spotify::Session::logMessageCallback,
    &Spotify::Session::endOfTrackCallback };

//Playlist container callbacks


/*sp_playlistcontainer_callbacks pc_callbacks = {
    &Spotify::Session::playlistAddedCallback,
    &Spotify::Session::playlistRemovedCallback,
    &Spotify::Session::playlistMovedCallback,
    &Spotify::Session::playListContainerLoadedCallback
};
*/

sp_playlistcontainer_callbacks pc_callbacks = {
    NULL,//&Spotify::Session::playlistAddedCallback,
    NULL,
    NULL,
    &Spotify::Session::playListContainerLoadedCallback
};

// Playlist Callbacks:

sp_playlist_callbacks pl_callbacks = {
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    &Spotify::Session::playlistMetadataUpdatedCallback
};

/*sp_playlist_callbacks pl_callbacks = {
    &Spotify::Session::tracksAddedCallback,
    &Spotify::Session::tracksRemovedCallback,
    &Spotify::Session::tracksMovedCallback,
    &Spotify::Session::playlistRenamedCallback,
    &Spotify::Session::playlistStateChangedCallback,
    &Spotify::Session::playlistUpdateInProgressCallback,
    &Spotify::Session::playlistMetadataUpdatedCallback
};
*/


#endif // CALLBACKS_H

==> qspot_0.9.9-4.tar.gz: qspot-0.9.9/src/qspotify_src/callbacks.h <==
//callbacks.h: libopenspotify callbacks
#ifndef CALLBACKS_H
#define CALLBACKS_H

#include "spotifysession.h"

// libopenspotify callback functions

sp_session_callbacks g_callbacks = {
    &Spotify::Session::loggedInCallback,
    &Spotify::Session::loggedOutCallback,
    &Spotify::Session::metadataUpdatedCallback,
    &Spotify::Session::connectionErrorCallback,
    &Spotify::Session::messageToUserCallback,
    &Spotify::Session::notifyMainThreadCallback,
    &Spotify::Session::musicDeliveryCallback,
    &Spotify::Session::playTokenLostCallback,
    &Spotify::Session::logMessageCallback,
    &Spotify::Session::endOfTrackCallback,
    &Spotify::Session::streamingError,
    NULL,
    NULL,
    NULL,
    NULL,
    &Spotify::Session::offlineStatusUpdated
};

//Playlist container callbacks


/*sp_playlistcontainer_callbacks pc_callbacks = {
    &Spotify::Session::playlistAddedCallback,
    &Spotify::Session::playlistRemovedCallback,
    &Spotify::Session::playlistMovedCallback,
    &Spotify::Session::playListContainerLoadedCallback
};
*/

sp_playlistcontainer_callbacks pc_callbacks = {
    NULL,//&Spotify::Session::playlistAddedCallback,
    NULL,
    NULL,
    &Spotify::Session::playListContainerLoadedCallback
};

// Playlist Callbacks:

sp_playlist_callbacks pl_callbacks = {
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    &Spotify::Session::playlistMetadataUpdatedCallback
};

/*sp_playlist_callbacks pl_callbacks = {
    &Spotify::Session::tracksAddedCallback,
    &Spotify::Session::tracksRemovedCallback,
    &Spotify::Session::tracksMovedCallback,
    &Spotify::Session::playlistRenamedCallback,
    &Spotify::Session::playlistStateChangedCallback,
    &Spotify::Session::playlistUpdateInProgressCallback,
    &Spotify::Session::playlistMetadataUpdatedCallback
};
*/


#endif // CALLBACKS_H
